"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.KafkaEnvelope = void 0;
const envelope_js_1 = require("./envelope.js");
const kafka_js_1 = require("../schemas/kafka.js");
const errors_js_1 = require("../errors.js");
/**
 * Kafka event envelope to extract data within body key
 * The record's body parameter is a string, though it can also be a JSON encoded string.
 * Regardless of its type it'll be parsed into a BaseModel object.
 *
 * Note: Records will be parsed the same way so if model is str,
 * all items in the list will be parsed as str and not as JSON (and vice versa)
 */
class KafkaEnvelope extends envelope_js_1.Envelope {
    static parse(data, schema) {
        // manually fetch event source to deside between Msk or SelfManaged
        const eventSource = data['eventSource'];
        const parsedEnvelope = eventSource === 'aws:kafka'
            ? kafka_js_1.KafkaMskEventSchema.parse(data)
            : kafka_js_1.KafkaSelfManagedEventSchema.parse(data);
        return Object.values(parsedEnvelope.records).map((topicRecord) => {
            return topicRecord.map((record) => {
                return super.parse(record.value, schema);
            });
        });
    }
    static safeParse(data, schema) {
        // manually fetch event source to deside between Msk or SelfManaged
        const eventSource = data['eventSource'];
        const parsedEnvelope = eventSource === 'aws:kafka'
            ? kafka_js_1.KafkaMskEventSchema.safeParse(data)
            : kafka_js_1.KafkaSelfManagedEventSchema.safeParse(data);
        if (!parsedEnvelope.success) {
            return {
                success: false,
                error: new errors_js_1.ParseError('Failed to parse Kafka envelope', {
                    cause: parsedEnvelope.error,
                }),
                originalEvent: data,
            };
        }
        const parsedRecords = [];
        for (const topicRecord of Object.values(parsedEnvelope.data.records)) {
            for (const record of topicRecord) {
                const parsedRecord = super.safeParse(record.value, schema);
                if (!parsedRecord.success) {
                    return {
                        success: false,
                        error: new errors_js_1.ParseError('Failed to parse Kafka record', {
                            cause: parsedRecord.error,
                        }),
                        originalEvent: data,
                    };
                }
                parsedRecords.push(parsedRecord.data);
            }
        }
        return {
            success: true,
            data: parsedRecords,
        };
    }
}
exports.KafkaEnvelope = KafkaEnvelope;
